@@ -120,6 +120,7 @@ class Application(Gtk.Application):
                              "Lollypop version",
                              None)
         self.connect("command-line", self.__on_command_line)
+        self.connect("handle-local-options", self.__on_handle_local_options)
         self.connect("activate", self.__on_activate)
         self.register(None)
         if self.get_is_remote():
@@ -233,9 +234,7 @@ class Application(Gtk.Application):
                 else:
                     self.settings.set_value("network-search",
                                             GLib.Variant("b", False))
-            t = Thread(target=self.__preload_portal)
-            t.daemon = True
-            t.start()
+            self.__preload_portal()
 
     def quit(self, vacuum=False):
         """
@@ -358,13 +357,15 @@ class Application(Gtk.Application):
             Preload lollypop portal
         """
         try:
-            bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
-            Gio.DBusProxy.new_sync(bus, Gio.DBusProxyFlags.NONE, None,
-                                   "org.gnome.Lollypop.Portal",
-                                   "/org/gnome/LollypopPortal",
-                                   "org.gnome.Lollypop.Portal", None)
-        except:
-            pass
+            bus = self.get_dbus_connection()
+            Gio.DBusProxy.new(bus, Gio.DBusProxyFlags.NONE, None,
+                              "org.gnome.Lollypop.Portal",
+                              "/org/gnome/LollypopPortal",
+                              "org.gnome.Lollypop.Portal", None, None)
+        except Exception as e:
+            print("You are missing lollypop-portal: "
+                  "https://github.com/gnumdk/lollypop-portal")
+            print("Application::__preload_portal():", e)
 
     def __init_proxy(self):
         """
@@ -382,6 +383,17 @@ class Application(Gtk.Application):
         except Exception as e:
             print("Application::__init_proxy()", e)
 
+    def __on_handle_local_options(self, app, options):
+        """
+            Handle local options
+            @param app as Gio.Application
+            @param options as GLib.VariantDict
+        """
+        if options.contains("version"):
+            print("Lollypop %s" % self.__version)
+            return 0
+        return -1
+
     def __on_command_line(self, app, app_cmd_line):
         """
             Handle command line
@@ -424,9 +436,6 @@ class Application(Gtk.Application):
             self.player.prev()
         elif options.contains("emulate-phone"):
             self.window.add_fake_phone()
-        elif options.contains("version"):
-            print("Lollypop %s" % self.__version)
-            exit(0)
         elif len(args) > 1:
             self.player.clear_externals()
             for uri in args[1:]:
@@ -478,7 +487,7 @@ class Application(Gtk.Application):
             @param event as Gdk.Event
         """
         if not self.settings.get_value("background-mode") or\
-                self.player.current_track.id is None:
+                not self.player.is_playing:
             GLib.timeout_add(500, self.quit, True)
         return widget.hide_on_delete()
 
