@@ -21,6 +21,7 @@ from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album
 from lollypop.utils import escape, is_readonly
 from lollypop.lio import Lio
+from lollypop.helper_dbus import DBusHelper
 
 
 class AlbumArt(BaseArt, TagReader):
@@ -247,25 +248,8 @@ class AlbumArt(BaseArt, TagReader):
         try:
             album = Album(album_id)
             arturi = None
-            # Check portal for kid3-cli
-            can_set_cover = False
-            try:
-                bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
-                proxy = Gio.DBusProxy.new_sync(
-                                            bus, Gio.DBusProxyFlags.NONE, None,
-                                            "org.gnome.Lollypop.Portal",
-                                            "/org/gnome/LollypopPortal",
-                                            "org.gnome.Lollypop.Portal", None)
-                can_set_cover = proxy.call_sync(
-                                               "CanSetCover", None,
-                                               Gio.DBusCallFlags.NO_AUTO_START,
-                                               500, None)[0]
-            except:
-                print("You are missing lollypop-portal: "
-                      "https://github.com/gnumdk/lollypop-portal")
             save_to_tags = Lp().settings.get_value("save-to-tags") and\
-                can_set_cover and not album.is_web
-
+                not album.is_web
             uri_count = Lp().albums.get_uri_count(album.uri)
             filename = self.get_album_cache_name(album) + ".jpg"
             if save_to_tags:
@@ -286,9 +270,8 @@ class AlbumArt(BaseArt, TagReader):
                     favorite.trash()
             else:
                 arturi = album.uri + "/" + self.__favorite
-            f = Lio.File.new_for_uri(arturi)
-            # Update cover file if exists even if we have written to tags
-            if not save_to_tags or f.query_exists():
+            # Save cover to uri
+            if not save_to_tags:
                 stream = Gio.MemoryInputStream.new_from_data(data, None)
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
                                                                stream,
@@ -306,6 +289,10 @@ class AlbumArt(BaseArt, TagReader):
                 del pixbuf
                 self.clean_album_cache(album)
                 GLib.idle_add(self.album_artwork_update, album.id)
+            else:
+                dst = Lio.File.new_for_uri(arturi)
+                if dst.query_exists():
+                    dst.trash()
         except Exception as e:
             print("Art::save_album_artwork(): %s" % e)
 
@@ -321,41 +308,15 @@ class AlbumArt(BaseArt, TagReader):
             Remove album artwork
             @param album as Album
         """
-        try:
-            for uri in self.get_album_artworks(album):
-                f = Lio.File.new_for_uri(uri)
-                try:
-                    f.trash()
-                except:
-                    f.delete(None)
-            # Check portal for kid3-cli
-            can_set_cover = False
+        for uri in self.get_album_artworks(album):
+            f = Lio.File.new_for_uri(uri)
             try:
-                bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
-                proxy = Gio.DBusProxy.new_sync(
-                                            bus, Gio.DBusProxyFlags.NONE, None,
-                                            "org.gnome.Lollypop.Portal",
-                                            "/org/gnome/LollypopPortal",
-                                            "org.gnome.Lollypop.Portal", None)
-                can_set_cover = proxy.call_sync(
-                                               "CanSetCover", None,
-                                               Gio.DBusCallFlags.NO_AUTO_START,
-                                               500, None)[0]
-            except Exception as e:
-                print("You are missing lollypop-portal: "
-                      "https://github.com/gnumdk/lollypop-portal", e)
-            if Lp().settings.get_value("save-to-tags") and can_set_cover:
-                for uri in Lp().albums.get_track_uris(album.id, [], []):
-                    try:
-                        path = GLib.filename_from_uri(uri)[0]
-                        proxy.call_sync("SetCover",
-                                        GLib.Variant("(ss)", (path, "")),
-                                        Gio.DBusCallFlags.NO_AUTO_START,
-                                        500, None)
-                    except Exception as e:
-                        print("AlbumArt::remove_album_artwork2():", e)
-        except Exception as e:
-            print("AlbumArt::remove_album_artwork3():", e)
+                f.trash()
+            except:
+                f.delete(None)
+        dbus_helper = DBusHelper()
+        dbus_helper.call("CanSetCover", None,
+                         self.__on_remove_album_artwork, album.id)
 
     def clean_album_cache(self, album):
         """
@@ -445,27 +406,60 @@ class AlbumArt(BaseArt, TagReader):
         f = Lio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
                                   self._CACHE_PATH)
         if f.query_exists():
-            for uri in Lp().albums.get_track_uris(album.id, [], []):
+            dbus_helper = DBusHelper()
+            dbus_helper.call("CanSetCover", None,
+                             self.__on_save_artwork_tags, album.id)
+
+    def __on_save_artwork_tags(self, source, result, album_id):
+        """
+            Save image to tags
+            @param source as GObject.Object
+            @param result as Gio.AsyncResult
+            @param album_id as int
+        """
+        try:
+            can_set_cover = source.call_finish(result)
+        except:
+            can_set_cover = False
+        if can_set_cover:
+            dbus_helper = DBusHelper()
+            for uri in Lp().albums.get_track_uris(album_id, [], []):
+                path = GLib.filename_from_uri(uri)[0]
+                dbus_helper.call("SetCover",
+                                 GLib.Variant(
+                                     "(ss)",
+                                     (path,
+                                      "%s/lollypop_cover_tags.jpg" %
+                                      self._CACHE_PATH)), None, None)
+            self.clean_album_cache(Album(album_id))
+            # FIXME Should be better to send all covers at once and listen
+            # to as signal but it works like this
+            GLib.timeout_add(2000, self.album_artwork_update, album_id)
+        else:
+            # Lollypop-portal or kid3-cli removed?
+            Lp().settings.set_value("save-to-tags", GLib.Variant("b", False))
+
+    def __on_remove_album_artwork(self, source, result, album_id):
+        """
+            Remove album image from tags
+            @param source as GObject.Object
+            @param result as Gio.AsyncResult
+            @param album_id
+        """
+        try:
+            can_set_cover = source.call_finish(result)
+        except:
+            can_set_cover = False
+        if can_set_cover:
+            dbus_helper = DBusHelper()
+            for uri in Lp().albums.get_track_uris(album_id, [], []):
                 try:
                     path = GLib.filename_from_uri(uri)[0]
-                    bus = Gio.bus_get_sync(Gio.BusType.SESSION, None)
-                    proxy = Gio.DBusProxy.new_sync(
-                                            bus, Gio.DBusProxyFlags.NONE, None,
-                                            "org.gnome.Lollypop.Portal",
-                                            "/org/gnome/LollypopPortal",
-                                            "org.gnome.Lollypop.Portal", None)
-                    proxy.call_sync("SetCover",
-                                    GLib.Variant(
-                                     "(ss)", (path,
-                                              "%s/lollypop_cover_tags.jpg" %
-                                              self._CACHE_PATH)),
-                                    Gio.DBusCallFlags.NO_AUTO_START,
-                                    500, None)
+                    dbus_helper.call("SetCover",
+                                     GLib.Variant("(ss)", (path, "")),
+                                     None, None)
                 except Exception as e:
-                    print("You are missing lollypop-portal: "
-                          "https://github.com/gnumdk/lollypop-portal", e)
-            f = Lio.File.new_for_path("%s/lollypop_cover_tags.jpg" %
-                                      self._CACHE_PATH)
-            f.delete()
-            self.clean_album_cache(album)
-            GLib.idle_add(self.album_artwork_update, album.id)
+                    print("AlbumArt::__on_remove_album_artwork():", e)
+        else:
+            # Lollypop-portal or kid3-cli removed?
+            Lp().settings.set_value("save-to-tags", GLib.Variant("b", False))
